#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://icculus.org/referencer/

# Package name
NAME="referencer"
# Package version
VERSION="1.1.5"
# Source code URL
SOURCE="http://icculus.org/referencer/downloads/referencer-$VERSION.tar.gz"
# ./configure options
CONFIGOPTIONS="--prefix=/usr --disable-update-mime-database"
# Files that should be placed in /usr/doc/package-version/
DOCS="AUTHORS COPYING ChangeLog INSTALL NEWS README TODO"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="i486"
CPU="i686"
BUILD="60.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: referencer is a document organiser and bibliography manager
$NAME:
$NAME: Referencer is a Gnome application to organise documents or 
$NAME: references, and ultimately generate a BibTeX bibliography file.
$NAME: Referencer includes a number of features to make this process
$NAME: easier: Automatic metadata retrieval, smart web links, import from
$NAME: BibTeX, Reference Manager and EndNote and tagging
$NAME:
$NAME:
$NAME:
$NAME:
END

# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION
if [ -f $NAME-$VERSION.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Check to see if icons are present. If it's not, download it
if [ -f icons.tar.gz ]; then
	echo "Icon file already here, no need to download";
else
 	echo "Downloading icon file"
	wget -c http://users.zenwalk.org/user-accounts/gapan/$NAME/icons.tar.gz
fi

# Unpack source
tar xvzf $NAME-$VERSION.tar.gz
tar xvzf icons.tar.gz

# Configure and make
cd $NAME-$VERSION
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
./configure $CONFIGOPTIONS
make

# Install on temporary directory
make install DESTDIR=$PKG

# Fix desktop file
sed -i -e 's/.svg//' $PKG/usr/share/applications/referencer.desktop

# Move icons to the right dir
mkdir -p $PKG/usr/share/icons/hicolor/scalable/apps
mv $PKG/usr/share/pixmaps/referencer.svg $PKG/usr/share/icons/hicolor/scalable/apps
rm -rf $PKG/usr/share/pixmaps
ICONSIZES="48 32 24 16"
for i in $ICONSIZES; do
	mkdir -p $PKG/usr/share/icons/hicolor/$i\x$i/apps;
	mv $CWD/$NAME-$i.png $PKG/usr/share/icons/hicolor/$i\x$i/apps/$NAME.png;
done;

# Strip binaries
cd $PKG
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $CWD/$NAME-$VERSION
cp -a $DOCS $PKG/usr/doc/$NAME-$VERSION

# Compress the man page(s)
find $PKG/usr/man -type f -exec gzip -9 {} \;

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Create the doinst.sh script to update the mime databases
cat << "EOF" > $PKG/install/doinst.sh
# update the mime desktop database
if [ -x usr/bin/update-desktop-database ]; then
        usr/bin/update-desktop-database -q
fi
# update the mime database
if [ -x usr/bin/update-mime-database ]; then
        usr/bin/update-mime-database usr/share/mime > /dev/null 2>&1
fi
EOF


# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
/sbin/makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME-$VERSION
rm -rf $PKG
